2021-03-26 Version: 1.0.3
- AMP Version Change.

2021-03-23 Version: 1.0.2
- Generated python2 2017-12-14 for BssOpenApi.

2021-03-19 Version: 1.0.1
- AMP Version Change.

2021-03-04 Version: 1.0.0
- AMP Version Change.

